@@ -209,8 +209,7 @@ renv_bootstrap_download_impl <- function(url, destfile) {
     quiet    = TRUE
   )
 
-  if ("headers" %in% names(formals(utils::download.file)))
-  {
+  if ("headers" %in% names(formals(utils::download.file))) {
     headers <- renv_bootstrap_download_custom_headers(url)
     if (length(headers) && is.character(headers))
       args$headers <- headers
@@ -298,9 +297,8 @@ renv_bootstrap_download_cran_latest_find <- function(version) {
 
       # add custom headers if available -- note that
       # utils::available.packages() will pass this to download.file()
-      if ("headers" %in% names(formals(utils::download.file)))
-      {
-        headers <- renv_bootstrap_download_custom_headers(url)
+      if ("headers" %in% names(formals(utils::download.file))) {
+        headers <- renv_bootstrap_download_custom_headers(repos)
         if (length(headers) && is.character(headers))
           args$headers <- headers
       }
