@@ -1,6 +1,7 @@
 
 #' Generate `renv.lock` from an RStudio Connect `manifest.json`
 #'
+#' @description
 #' Use `renv_lockfile_from_manifest()` to convert a `manifest.json` file from
 #' an RStudio Connect content bundle into an `renv.lock` lockfile.
 #'
@@ -20,18 +21,11 @@
 #'   object; otherwise, the lockfile will be written to the path specified by
 #'   `lockfile`.
 #'
-#' @details
-#' By default the `lockfile` argument is set to `NA`. This will not create a new
-#' `renv.lock` file. Rather, it will return a lockfile object (see `?lockfile`)
-#' that can be used to create a new `renv.lock` file. If `lockfile` is set to a
-#' character string, a new file will be created with that path -- e.g.
-#' `renv.lock` -- and the lockfile object will be returned.
-#'
 #' @return
 #' An renv lockfile.
 #'
 #' @keywords internal
-renv_lockfile_from_manifest <- function(manifest,
+renv_lockfile_from_manifest <- function(manifest = "manifest.json",
                                         lockfile = NA,
                                         project = NULL)
 {
@@ -79,10 +73,8 @@ renv_lockfile_from_manifest <- function(manifest,
   if (is.na(lockfile))
     return(lock)
 
-  # otherwise, write to file and report for user
+  # otherwise, write to file
   renv_lockfile_write(lock, file = lockfile)
-  fmt <- "- Lockfile written to %s."
-  writef(fmt, renv_path_pretty(lockfile))
 
   invisible(lock)
 
