@@ -1,6 +1,4 @@
 
-context("Defer")
-
 test_that("defer evaluates in appropriate environment", {
 
   foo <- function() {
@@ -40,10 +38,21 @@ test_that("defer evaluates in appropriate environment", {
 
 })
 
+test_that("defer runs handles in LIFO order", {
+  x <- double()
+  local({
+    defer(x <<- c(x, 1))
+    defer(x <<- c(x, 2))
+    defer(x <<- c(x, 3))
+  })
+
+  expect_equal(x, c(3, 2, 1))
+})
+
 test_that("defer captures arguments properly", {
 
   foo <- function(x) {
-    defer(writeLines(x), envir = parent.frame())
+    defer(writeLines(x), scope = parent.frame())
   }
 
   bar <- function(y) {
@@ -64,7 +73,7 @@ test_that("defer works with arbitrary expressions", {
     defer({
       x + 1
       writeLines("> foo")
-    }, envir = parent.frame())
+    }, scope = parent.frame())
   }
 
   bar <- function() {
@@ -78,3 +87,12 @@ test_that("defer works with arbitrary expressions", {
   expect_identical(output, expected)
 
 })
+
+
+test_that("renv_defer_execute can run handlers earlier", {
+  x <- 1
+  defer(rm(list = "x"))
+  expect_true(exists("x", inherits = FALSE))
+  renv_defer_execute(environment())
+  expect_false(exists("x", inherits = FALSE))
+})
